//
//  GUI.cpp
//  TestSine
//
//  Created by Erik Zorzin on 22/10/15.
//  Copyright © 2015 Erik Zorzin. All rights reserved.
//

#include "GUI.hpp"

enum SlidersIDs
{
    A_sld_ID
};

GUI::GUI(const TGWindow* p, UInt_t w, UInt_t h)
{
    fMain = new TGMainFrame(p, w, h);                                                                                           // Creating main frame...
    fEcanvas = new TRootEmbeddedCanvas("Ecanvas", fMain, w, h);                                                                 // Creating canvas...
    fMain->AddFrame(fEcanvas, new TGLayoutHints(kLHintsExpandX|kLHintsExpandY, 10, 10, 10, 1));                                 // Adding canvas to main frame...
    fMain->SetWindowName("TestSine");                                                                                           // Setting main frame name...
    A_sld = new TGHSlider(fMain, 150, kSlider1|kScaleDownRight, A_sld_ID);                                                      // Creating "A_sld" slider...
    A_sld->Connect("PositionChanged(Int_t)", "GUI", this, "DoSlider(Int_t)");                                                   // Connecting "A_sld" silder with "Do_A_sld" method...
    A_sld->SetRange(0, 100);                                                                                                    // Setting the range of the slider...
    fMain->AddFrame(A_sld, new TGLayoutHints(kLHintsCenterX, 5, 5, 3, 4));                                                      // Adding slider to main frame...
    
    /*-------------------------------------------------------------------------------------------------------------------------*/
    /*--------------------------------------------------- CREATING THE CANVAS -------------------------------------------------*/
    /*-------------------------------------------------------------------------------------------------------------------------*/
    fMain->Connect("CloseWindow()", "GUI", this, "CloseApplication()");                                                         // Closing the window will terminate the application...
   
    /*-------------------------------------------------------------------------------------------------------------------------*/
    /*----------------------------------------------------- CREATING A PAD ----------------------------------------------------*/
    /*-------------------------------------------------------------------------------------------------------------------------*/
    pad = new TPad("pad", "MyPad",0.1 , 0.1, 0.98, 0.98);                                                                       // Creating new pad...

    /*-------------------------------------------------------------------------------------------------------------------------*/
    /*----------------------------------------------------- CREATING A GRAPH --------------------------------------------------*/
    /*-------------------------------------------------------------------------------------------------------------------------*/
    int             i;                                                                                                          // Integer counter.
    double          omega = 2*3.14*F;                                                                                             // Pulsation [rad/s].
    double          dt = 1.0/FS;                                                                                                // "dt" [s].
    double          t[N];                                                                                                       // "t" variable: time [s].
    double          s[N];                                                                                                       // "s" variable: displacement [m].
    
    for (i = 0; i < N; i++)
    {
        t[i] = i*dt;
        s[i] = A*sin(omega*t[i]);
    }
    
    graph = new TGraph(N, t, s);                                                                                                // Creating new scatter plot graph...
    graph->SetLineColor(2);                                                                                                     // Setting line color...
    graph->SetLineWidth(4);                                                                                                     // Setting line width...
    graph->SetTitle("sin(x)");                                                                                                  // Setting graph title...
    graph->GetXaxis()->SetTitle("x");                                                                                           // Setting x-axis title...
    graph->GetYaxis()->SetTitle("sin(x)");                                                                                      // Setting y-axis title...
    graph->SetMarkerColor(4);
    graph->SetMarkerStyle(21);
    
    /*-------------------------------------------------------------------------------------------------------------------------*/
    /*----------------------------------------------------- DRAWING OBJECTS ---------------------------------------------------*/
    /*-------------------------------------------------------------------------------------------------------------------------*/
    pad->Draw();                                                                                                                // Drawing the pad into the canvas...
    pad->cd();                                                                                                                  // Going into the pad...
    graph->Draw();                                                                                                              // Drawing the graph into the pad...
    pad->SetEditable(kFALSE);                                                                                                   // Disabling GUI editing...
    
    /*-------------------------------------------------------------------------------------------------------------------------*/
    /*----------------------------------------------------- UPDATING OBJECTS --------------------------------------------------*/
    /*-------------------------------------------------------------------------------------------------------------------------*/
    fMain->MapSubwindows();
    fMain->MapWindow();
    gClient->WaitFor(fMain);

    
}

GUI::~GUI()
{
    gApplication->Terminate(0);
    delete fMain;
}

void GUI::DoSlider(Int_t pos)
{
    Int_t       id;
    TGSlider*   slider = (TGSlider*) gTQSender;
    double A;
    id = slider->WidgetId();
    A = pos/100.0;
    printf("A = %lf", A);
}

void GUI::CloseApplication()
{
    gApplication->Terminate(0);
}



